@@ -9,15 +9,14 @@ use {
         },
     },
     solana_client::rpc_client::RpcClient,
-    solana_core::rpc::JsonRpcConfig,
     solana_faucet::faucet::{run_local_faucet_with_port, FAUCET_PORT},
+    solana_rpc::rpc::JsonRpcConfig,
     solana_sdk::{
         account::AccountSharedData,
         clock::Slot,
         epoch_schedule::{EpochSchedule, MINIMUM_SLOTS_PER_EPOCH},
         native_token::sol_to_lamports,
         pubkey::Pubkey,
-        rent::Rent,
         rpc_port,
         signature::{read_keypair_file, write_keypair_file, Keypair, Signer},
         system_program,
@@ -69,7 +68,7 @@ fn main() {
                 .takes_value(true)
                 .help("Configuration file to use");
             if let Some(ref config_file) = *solana_cli_config::CONFIG_FILE {
-                arg.default_value(&config_file)
+                arg.default_value(config_file)
             } else {
                 arg
             }
@@ -562,8 +561,6 @@ fn main() {
             slots_per_epoch,
             /* enable_warmup_epochs = */ false,
         ));
-
-        genesis.rent = Rent::with_slots_per_epoch(slots_per_epoch);
     }
 
     if let Some(gossip_host) = gossip_host {
